@@ -18,7 +18,7 @@ class ModelConfigPane(TraitsDockPane):
 
     model = Instance(HasTraits)
 
-    view = View(Item('model',
+    view = View(Item('pane.model',
                      style = 'custom',
                      show_label = False),
                 resizable = True)
